@@ -16,6 +16,7 @@
 import struct
 from . import packet_base
 from . import vlan
+from . import mpls
 from ryu.ofproto import ether
 
 
@@ -43,3 +44,4 @@ class ethernet(packet_base.PacketBase):
 # copy vlan _TYPES
 ethernet._TYPES = vlan.vlan._TYPES
 ethernet.register_packet_type(vlan.vlan, ether.ETH_TYPE_8021Q)
+ethernet.register_packet_type(mpls.mpls, ether.ETH_TYPE_MPLS)
